# Image Processing Cesar

Description.
The package Image Processing Cesar is used to:
Processing: - Histogram matching - Structural similarity - Resize image
Utils: - Read image - Save image - Plot image - Plot result - Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install image_processing_cesarhvb
```

## Usage

```python
from package_name.module1_name import file1_name
file1_name.my_function()
```

## Author

César Henrique

## License

[MIT](https://choosealicense.com/licenses/mit/)
